[![Build status](https://raw.githubusercontent.com/MPI-IS-BambooAgent/sw_badges/master/badges/plans/citygraph/tag.svg?sanitize=true)](https://github.com/MPI-IS-BambooAgent/sw_badges)

CityGraph
=========
Framework for representing and moving around a city.
